@@ -26,13 +26,11 @@ from .webdriver_chaining import Steps
 
 from .skip import *
 from .driver import *
-from .logging.log import *
 from .testdata.parameterization import *
 
-from .request import HttpRequest
 
 __author__ = "bugmaster"
 
-__version__ = "2.7.0"
+__version__ = "2.10.7"
 
 __description__ = "WebUI/HTTP automation testing framework based on unittest."
