@@ -1,16 +1,16 @@
 import unittest
 from urllib.parse import unquote
-import jmespath
 from time import sleep
 from jsonschema import validate
 from jsonschema.exceptions import ValidationError
+from selenium.webdriver.common.by import By
+from seldom.driver import Browser
 from seldom.webdriver import WebDriver
-from seldom.request import HttpRequest
-from seldom.running.config import Seldom
+from seldom.request import HttpRequest, ResponseResult, formatting
+from seldom.running.config import Seldom, BrowserConfig
 from seldom.logging import log
 from seldom.logging.exceptions import NotFindElementError
-from seldom.utils import diff_json, AssertInfo
-from seldom.request import ResponseResult
+from seldom.utils import diff_json, AssertInfo, jmespath
 
 
 class TestCase(unittest.TestCase, WebDriver, HttpRequest):
@@ -61,7 +61,23 @@ class TestCase(unittest.TestCase, WebDriver, HttpRequest):
         """
         return Seldom.driver
 
-    def assertTitle(self, title=None, msg=None):
+    @staticmethod
+    def browser(name: str):
+        """
+        launch browser
+        :param name: browser name
+        """
+        Seldom.driver = Browser(name=name)
+
+    @staticmethod
+    def new_browser():
+        """
+        launch new browser
+        """
+        browser = Browser(BrowserConfig.NAME)
+        return browser
+
+    def assertTitle(self, title=None, msg=None) -> None:
         """
         Asserts whether the current title is in line with expectations.
 
@@ -70,20 +86,18 @@ class TestCase(unittest.TestCase, WebDriver, HttpRequest):
         """
         if title is None:
             raise AssertionError("The assertion title cannot be empty.")
+
+        log.info(f"👀 assertTitle -> {title}.")
         for _ in range(Seldom.timeout + 1):
             try:
                 self.assertEqual(title, Seldom.driver.title)
-                log.info("👀 assert title: {title}.".format(
-                    title=Seldom.driver.title))
                 break
             except AssertionError:
                 sleep(1)
         else:
-            print("abc")
-            log.warn("❌ assert fail: {title}.".format(title=title))
             self.assertEqual(title, Seldom.driver.title, msg=msg)
 
-    def assertInTitle(self, title=None, msg=None):
+    def assertInTitle(self, title=None, msg=None) -> None:
         """
         Asserts whether the current title is in line with expectations.
 
@@ -92,19 +106,18 @@ class TestCase(unittest.TestCase, WebDriver, HttpRequest):
         """
         if title is None:
             raise AssertionError("The assertion title cannot be empty.")
+
+        log.info(f"👀 assertInTitle -> {title}.")
         for _ in range(Seldom.timeout + 1):
             try:
                 self.assertIn(title, Seldom.driver.title)
-                log.info("👀 assertIn title: {title}.".format(
-                    title=Seldom.driver.title))
                 break
             except AssertionError:
                 sleep(1)
         else:
-            log.warn("❌ assertIn fail: {title}.".format(title=title))
             self.assertIn(title, Seldom.driver.title, msg=msg)
 
-    def assertUrl(self, url, msg=None):
+    def assertUrl(self, url=None, msg=None) -> None:
         """
         Asserts whether the current URL is in line with expectations.
 
@@ -113,19 +126,19 @@ class TestCase(unittest.TestCase, WebDriver, HttpRequest):
         """
         if url is None:
             raise AssertionError("The assertion URL cannot be empty.")
+
+        log.info(f"👀 assertUrl -> {url}.")
         for _ in range(Seldom.timeout + 1):
             current_url = unquote(Seldom.driver.current_url)
             try:
                 self.assertEqual(url, current_url)
-                log.info("👀 assert url: {url}.".format(url=current_url))
                 break
             except AssertionError:
                 sleep(1)
         else:
-            log.warn("❌ assert fail: {url}.".format(url=url))
             self.assertEqual(url, Seldom.driver.current_url, msg=msg)
 
-    def assertInUrl(self, url=None, msg=None):
+    def assertInUrl(self, url=None, msg=None) -> None:
         """
         Asserts whether the current URL is in line with expectations.
 
@@ -134,19 +147,20 @@ class TestCase(unittest.TestCase, WebDriver, HttpRequest):
         """
         if url is None:
             raise AssertionError("The assertion URL cannot be empty.")
+
+        log.info(f"👀 assertInUrl -> {url}.")
         for _ in range(Seldom.timeout + 1):
             current_url = unquote(Seldom.driver.current_url)
             try:
                 self.assertIn(url, current_url)
-                log.info("👀 assertIn url: {url}.".format(url=current_url))
+
                 break
             except AssertionError:
                 sleep(1)
         else:
-            log.warn("❌ assertIn fail: {url}.".format(url=url))
             self.assertIn(url, Seldom.driver.current_url, msg=msg)
 
-    def assertText(self, text=None, msg=None):
+    def assertText(self, text=None, msg=None) -> None:
         """
         Asserts whether the text of the current page conforms to expectations.
 
@@ -156,19 +170,19 @@ class TestCase(unittest.TestCase, WebDriver, HttpRequest):
         if text is None:
             raise AssertionError("The assertion text cannot be empty.")
 
-        elem = Seldom.driver.find_element_by_tag_name("html")
+        elem = Seldom.driver.find_element(By.TAG_NAME, "html")
+        log.info(f"👀 assertText -> {text}.")
         for _ in range(Seldom.timeout + 1):
             if elem.is_displayed():
                 try:
                     self.assertIn(text, elem.text)
-                    log.info("👀 assertText: {text}.".format(text=text))
                     break
                 except AssertionError:
                     sleep(1)
         else:
             self.assertIn(text, elem.text, msg=msg)
 
-    def assertNotText(self, text=None, msg=None):
+    def assertNotText(self, text=None, msg=None) -> None:
         """
         Asserts that the current page does not contain the specified text.
 
@@ -178,19 +192,21 @@ class TestCase(unittest.TestCase, WebDriver, HttpRequest):
         if text is None:
             raise AssertionError("The assertion text cannot be empty.")
 
-        elem = Seldom.driver.find_element_by_tag_name("html")
+        elem = Seldom.driver.find_element(By.TAG_NAME, "html")
+
+        log.info(f"👀 assertNotText -> {text}.")
         for _ in range(Seldom.timeout + 1):
             if elem.is_displayed():
                 try:
                     self.assertNotIn(text, elem.text)
-                    log.info("👀 assertNotText: {text}.".format(text=text))
+
                     break
                 except AssertionError:
                     sleep(1)
         else:
             self.assertNotIn(text, elem.text, msg=msg)
 
-    def assertAlertText(self, text=None, msg=None):
+    def assertAlertText(self, text=None, msg=None) -> None:
         """
         Asserts whether the text of the current page conforms to expectations.
 
@@ -199,22 +215,31 @@ class TestCase(unittest.TestCase, WebDriver, HttpRequest):
         """
         if text is None:
             raise NameError("Alert text cannot be empty.")
-        alert_text = Seldom.driver.switch_to.alert.text
-        self.assertEqual(alert_text, text, msg=msg)
 
-    def assertElement(self, index=0, msg=None, **kwargs):
+        log.info(f"👀 assertAlertText -> {text}.")
+        alert_text = Seldom.driver.switch_to.alert.text
+        for _ in range(Seldom.timeout + 1):
+            try:
+                self.assertEqual(alert_text, text, msg=msg)
+            except AssertionError:
+                sleep(1)
+        else:
+            self.assertEqual(alert_text, text, msg=msg)
+
+    def assertElement(self, index=0, msg=None, **kwargs) -> None:
         """
         Asserts whether the element exists.
 
         Usage:
         self.assertElement(css="#id")
         """
+        log.info("👀 assertElement.")
         if msg is None:
             msg = "No element found"
+
         elem = True
         for _ in range(Seldom.timeout + 1):
             try:
-                log.info("👀 assertElement.")
                 self.get_element(index=index, **kwargs)
                 elem = True
                 break
@@ -224,63 +249,85 @@ class TestCase(unittest.TestCase, WebDriver, HttpRequest):
 
         self.assertTrue(elem, msg=msg)
 
-    def assertNotElement(self, index=0, msg=None, **kwargs):
+    def assertNotElement(self, index=0, msg=None, **kwargs) -> None:
         """
         Asserts if the element does not exist.
 
         Usage:
         self.assertNotElement(css="#id")
         """
+        log.info("👀 assertNotElement.")
         if msg is None:
             msg = "Find the element"
+
+        timeout_backups = Seldom.timeout
+        Seldom.timeout = 2
         try:
-            log.info("👀 assertNotElement.")
             self.get_element(index=index, **kwargs)
             elem = True
         except NotFindElementError:
             elem = False
 
+        Seldom.timeout = timeout_backups
+
         self.assertFalse(elem, msg=msg)
 
-    def assertStatusCode(self, status_code, msg=None):
+    def assertStatusCode(self, status_code, msg=None) -> None:
         """
         Asserts the HTTP status code
         """
+        log.info(f"👀 assertStatusCode -> {status_code}.")
         self.assertEqual(ResponseResult.status_code, status_code, msg=msg)
 
-    def assertSchema(self, schema):
+    def assertSchema(self, schema, response=None) -> None:
         """
         Assert JSON Schema
         doc: https://json-schema.org/
         """
+        log.info(f"👀 assertSchema -> {formatting(schema)}.")
+
+        if response is None:
+            response = ResponseResult.response
+
         try:
-            validate(instance=ResponseResult.response, schema=schema)
+            validate(instance=response, schema=schema)
         except ValidationError as msg:
             self.assertEqual("Response data", "Schema data", msg)
         else:
             self.assertTrue(True)
 
-    def assertJSON(self, assert_json):
+    def assertJSON(self, assert_json, response=None) -> None:
         """
         Assert JSON data
         """
+        log.info(f"👀 assertJSON -> {assert_json}.")
+        if response is None:
+            response = ResponseResult.response
+
         AssertInfo.data = []
-        diff_json(ResponseResult.response, assert_json)
+        diff_json(response, assert_json)
         if len(AssertInfo.data) == 0:
             self.assertTrue(True)
         else:
             self.assertEqual("Response data", "Assert data", msg=AssertInfo.data)
 
-    def assertPath(self, path, value):
+    def assertPath(self, path, value) -> None:
         """
         Assert path data
         doc: https://jmespath.org/
         """
-        search_value = jmespath.search(path, ResponseResult.response)
-        if search_value is None:
-            self.assertEqual(path, None, msg="{} No match".format(path))
-        else:
-            self.assertEqual(search_value, value)
+        log.info(f"👀 assertPath -> {path} >> {value}.")
+        search_value = jmespath(ResponseResult.response, path)
+        self.assertEqual(search_value, value)
+
+    def assertInPath(self, path, value) -> None:
+        """
+        Assert path data
+        doc: https://jmespath.org/
+        """
+        log.info(f"👀 assertInPath -> {path} >> {value}.")
+        search_value = jmespath(ResponseResult.response, path)
+        self.assertIn(value, search_value)
 
     def xSkip(self, reason):
         """
