@@ -11,6 +11,8 @@ class Seldom:
     timeout = 10
     debug = False
     base_url = None
+    env = None
+    api_data_url = None
 
 
 class BrowserConfig:
