@@ -11,6 +11,7 @@ from selenium.webdriver.common.action_chains import ActionChains
 from seldom.logging import log
 from seldom.running.config import Seldom
 from seldom.logging.exceptions import NotFindElementError
+from selenium.webdriver.chrome.service import Service as cService
 from seldom.utils.webdriver_manager_extend import ChromeDriverManager
 
 __all__ = ["WebDriver", "WebElement"]
@@ -218,7 +219,7 @@ class WebDriver(object):
         """
         log.info("📖 {}".format(url))
         if isinstance(Seldom.driver, SeleniumWebDriver) is False:
-            Seldom.driver = Chrome(executable_path=ChromeDriverManager().install())
+            Seldom.driver = Chrome(service=cService(ChromeDriverManager().install()))
         Seldom.driver.get(url)
 
     def open(self, url: str) -> None:
@@ -369,7 +370,7 @@ class WebDriver(object):
         ActionChains(Seldom.driver).click_and_hold(elem).perform()
 
     @staticmethod
-    def drag_and_drop_by_offset(index:int = 0, x: int = 0, y: int = 0, **kwargs) -> None:
+    def drag_and_drop_by_offset(index: int = 0, x: int = 0, y: int = 0, **kwargs) -> None:
         """
         Holds down the left mouse button on the source element,
            then moves to the target offset and releases the mouse button.
@@ -422,7 +423,9 @@ class WebDriver(object):
         Usage:
             self.close()
         """
-        Seldom.driver.close()
+        if isinstance(Seldom.driver, SeleniumWebDriver) is True:
+            Seldom.driver.close()
+            Seldom.driver = None
 
     @staticmethod
     def quit() -> None:
@@ -616,6 +619,18 @@ class WebDriver(object):
         log.info("✅ {} -> switch to frame.".format(web_elem.info))
         Seldom.driver.switch_to.frame(elem)
 
+    @staticmethod
+    def switch_to_frame_parent() -> None:
+        """
+        Switches focus to the parent context. If the current context is the top
+        level browsing context, the context remains unchanged.
+
+        Usage:
+            self.switch_to_frame_parent()
+        """
+        log.info("✅ switch to parent frame.")
+        Seldom.driver.switch_to.parent_frame()
+
     @staticmethod
     def switch_to_frame_out() -> None:
         """
@@ -643,6 +658,20 @@ class WebDriver(object):
         all_handles = Seldom.driver.window_handles
         Seldom.driver.switch_to.window(all_handles[window])
 
+    @staticmethod
+    def switch_to_new_window(type_hint=None) -> None:
+        """
+        Switches to a new top-level browsing context.
+
+        The type hint can be one of "tab" or "window". If not specified the
+        browser will automatically select it.
+
+        :Usage:
+            self.switch_to_new_window('tab')
+        """
+        log.info("✅ switch to new window.")
+        Seldom.driver.switch_to.new_window(type_hint=type_hint)
+
     def screenshots(self, file_path: str = None) -> None:
         """
         Saves a screenshots of the current window to a PNG image file.
@@ -760,7 +789,7 @@ class WebDriver(object):
                 {'name' : 'foo', 'value' : 'bar'},
                 {'name' : 'foo', 'value' : 'bar'}
             ]
-            self.add_cookie(cookie_list)
+            self.add_cookies(cookie_list)
         """
         if isinstance(cookie_list, list):
             for cookie in cookie_list:
@@ -816,9 +845,9 @@ class WebDriver(object):
             for i in range(len(ret)):
                 js = 'return document.querySelectorAll("{css}")[{i}].outerHTML;'.format(css=css, i=i)
                 ret = Seldom.driver.execute_script(js)
-                print("{} ->".format(i), ret)
+                log.info("{} ->".format(i), ret)
         else:
-            log.warn("No elements were found.")
+            log.warning("No elements were found.")
 
     @staticmethod
     def get_elements(**kwargs):
@@ -832,7 +861,7 @@ class WebDriver(object):
         web_elem = WebElement(**kwargs)
         elems = web_elem.get_elements()
         if len(elems) == 0:
-            log.warn("{}.".format(web_elem.warn))
+            log.warning("{}.".format(web_elem.warn))
         else:
             log.info("✅ {}.".format(web_elem.info))
         return elems
